# Examples

- [Dating Profile](dating_profiles.md): Build dating profiles from descriptions using prompt templating and JSON-guided generation.
- [Chain Of Density](chain_of_density.md): Summarize documents using chain of density prompting and JSON-guided generation.
